@@ -549,7 +549,7 @@ display_get_device_guid (bmc_info_state_data_t *state_data)
   if (ipmi_cmd_get_device_guid (state_data->ipmi_ctx, obj_cmd_rs) < 0)
     {
       if (!state_data->prog_data->args->get_device_guid
-          && ipmi_ctx_errnum (state_data->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE
+          && ipmi_ctx_errnum (state_data->ipmi_ctx) == IPMI_ERR_COMMAND_INVALID_OR_UNSUPPORTED
           && ipmi_check_completion_code (obj_cmd_rs,
                                          IPMI_COMP_CODE_INVALID_COMMAND) == 1)
         {
@@ -713,13 +713,14 @@ display_system_info_common (bmc_info_state_data_t *state_data,
                           obj_cmd_first_set_rs) < 0)
     {
       if (!state_data->prog_data->args->get_system_info
-          && ipmi_ctx_errnum (state_data->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE
-          && (ipmi_check_completion_code (obj_cmd_first_set_rs,
-					  IPMI_COMP_CODE_INVALID_COMMAND) == 1
-	      || ipmi_check_completion_code (obj_cmd_first_set_rs,
-					     IPMI_COMP_CODE_GET_SYSTEM_INFO_PARAMETERS_PARAMETER_NOT_SUPPORTED) == 1
-	      || ipmi_check_completion_code (obj_cmd_first_set_rs,
-					     IPMI_COMP_CODE_INVALID_DATA_FIELD_IN_REQUEST) == 1))
+	  && ((ipmi_ctx_errnum (state_data->ipmi_ctx) == IPMI_ERR_COMMAND_INVALID_OR_UNSUPPORTED
+	       && (ipmi_check_completion_code (obj_cmd_first_set_rs,
+					       IPMI_COMP_CODE_INVALID_COMMAND) == 1
+		   || ipmi_check_completion_code (obj_cmd_first_set_rs,
+						  IPMI_COMP_CODE_INVALID_DATA_FIELD_IN_REQUEST) == 1))
+	      || (ipmi_ctx_errnum (state_data->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE
+		  && ipmi_check_completion_code (obj_cmd_first_set_rs,
+						 IPMI_COMP_CODE_GET_SYSTEM_INFO_PARAMETERS_PARAMETER_NOT_SUPPORTED) == 1)))
         {
           rv = 0;
           goto cleanup;
@@ -806,13 +807,14 @@ display_system_info_common (bmc_info_state_data_t *state_data,
                     obj_cmd_rs) < 0)
         {
           if (!state_data->prog_data->args->get_system_info
-              && ipmi_ctx_errnum (state_data->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE
-              && (ipmi_check_completion_code (obj_cmd_rs,
-					      IPMI_COMP_CODE_INVALID_COMMAND) == 1
-		  || ipmi_check_completion_code (obj_cmd_rs,
-						 IPMI_COMP_CODE_GET_SYSTEM_INFO_PARAMETERS_PARAMETER_NOT_SUPPORTED) == 1
-		  || ipmi_check_completion_code (obj_cmd_rs,
-						 IPMI_COMP_CODE_INVALID_DATA_FIELD_IN_REQUEST) == 1))
+	      && ((ipmi_ctx_errnum (state_data->ipmi_ctx) == IPMI_ERR_COMMAND_INVALID_OR_UNSUPPORTED
+		   && (ipmi_check_completion_code (obj_cmd_first_set_rs,
+						   IPMI_COMP_CODE_INVALID_COMMAND) == 1
+		       || ipmi_check_completion_code (obj_cmd_first_set_rs,
+						      IPMI_COMP_CODE_INVALID_DATA_FIELD_IN_REQUEST) == 1))
+		  || (ipmi_ctx_errnum (state_data->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE
+		      && ipmi_check_completion_code (obj_cmd_first_set_rs,
+						     IPMI_COMP_CODE_GET_SYSTEM_INFO_PARAMETERS_PARAMETER_NOT_SUPPORTED) == 1)))
             {
               rv = 0;
               goto cleanup;
