@@ -467,11 +467,12 @@ config_is_non_fatal_error (ipmi_ctx_t ipmi_ctx,
 
   if (!IPMI_ERRNUM_IS_FATAL_ERROR (ipmi_ctx))
     {
-      if (ipmi_ctx_errnum (ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE
-          && (ipmi_check_completion_code (obj_cmd_rs,
-                                          IPMI_COMP_CODE_INVALID_DATA_FIELD_IN_REQUEST) == 1
-              || ipmi_check_completion_code (obj_cmd_rs,
-                                             IPMI_COMP_CODE_REQUEST_PARAMETER_NOT_SUPPORTED) == 1))
+      if ((ipmi_ctx_errnum (ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE
+	   && ipmi_check_completion_code (obj_cmd_rs,
+					  IPMI_COMP_CODE_REQUEST_PARAMETER_NOT_SUPPORTED) == 1)
+	  || (ipmi_ctx_errnum (ipmi_ctx) == IPMI_ERR_COMMAND_INVALID_OR_UNSUPPORTED
+	      && ipmi_check_completion_code (obj_cmd_rs,
+					     IPMI_COMP_CODE_INVALID_DATA_FIELD_IN_REQUEST) == 1))
         (*non_fatal_err) = CONFIG_ERR_NON_FATAL_ERROR_INVALID_UNSUPPORTED_CONFIG;
       else
         (*non_fatal_err) = CONFIG_ERR_NON_FATAL_ERROR;
@@ -511,11 +512,12 @@ config_is_config_param_non_fatal_error (ipmi_ctx_t ipmi_ctx,
                && ipmi_check_completion_code (obj_cmd_rs,
                                               IPMI_COMP_CODE_SET_LAN_CONFIGURATION_PARAMETERS_PARAMETER_NOT_SUPPORTED) == 1)
         (*non_fatal_err) = CONFIG_ERR_NON_FATAL_ERROR_NOT_SUPPORTED;
-      else if (ipmi_ctx_errnum (ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE
-               && (ipmi_check_completion_code (obj_cmd_rs,
-                                               IPMI_COMP_CODE_INVALID_DATA_FIELD_IN_REQUEST) == 1
-                   || ipmi_check_completion_code (obj_cmd_rs,
-                                                  IPMI_COMP_CODE_REQUEST_PARAMETER_NOT_SUPPORTED) == 1))
+      else if ((ipmi_ctx_errnum (ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE
+		&& ipmi_check_completion_code (obj_cmd_rs,
+					       IPMI_COMP_CODE_REQUEST_PARAMETER_NOT_SUPPORTED) == 1)
+	       || (ipmi_ctx_errnum (ipmi_ctx) == IPMI_ERR_COMMAND_INVALID_OR_UNSUPPORTED
+		   && ipmi_check_completion_code (obj_cmd_rs,
+						  IPMI_COMP_CODE_INVALID_DATA_FIELD_IN_REQUEST) == 1))
         (*non_fatal_err) = CONFIG_ERR_NON_FATAL_ERROR_INVALID_UNSUPPORTED_CONFIG;
       else
         (*non_fatal_err) = CONFIG_ERR_NON_FATAL_ERROR;
