@@ -1,7 +1,7 @@
 /***************************************************************************** \
  *  $Id: ipmi-fru-argp.c,v 1.33 2010-02-08 22:20:58 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007-2012 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2013 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Albert Chu <chu11@llnl.gov>
@@ -54,7 +54,7 @@
 
 const char *argp_program_version =
   "ipmi-fru - " PACKAGE_VERSION "\n"
-  "Copyright (C) 2007-2012 Lawrence Livermore National Security, LLC.\n"
+  "Copyright (C) 2007-2013 Lawrence Livermore National Security, LLC.\n"
   "Copyright (C) 2007 The Regents of the University of California.\n"
   "This program is free software; you may redistribute it under the terms of\n"
   "the GNU General Public License.  This program has absolutely no warranty.";
@@ -80,6 +80,7 @@ static struct argp_option cmdline_options[] =
     ARGP_COMMON_SDR_CACHE_OPTIONS,
     ARGP_COMMON_SDR_CACHE_OPTIONS_FILE_DIRECTORY,
     ARGP_COMMON_SDR_CACHE_OPTIONS_IGNORE,
+    ARGP_COMMON_TIME_OPTIONS,
     ARGP_COMMON_HOSTRANGED_OPTIONS,
     ARGP_COMMON_OPTIONS_DEBUG,
     { "device-id", DEVICE_ID_KEY, "DEVICE_ID", 0,
@@ -181,7 +182,7 @@ _ipmi_fru_config_file_parse (struct ipmi_fru_arguments *cmd_args)
   if (config_file_parse (cmd_args->common_args.config_file,
                          0,
                          &(cmd_args->common_args),
-                         CONFIG_FILE_INBAND | CONFIG_FILE_OUTOFBAND | CONFIG_FILE_SDR | CONFIG_FILE_HOSTRANGE,
+                         CONFIG_FILE_INBAND | CONFIG_FILE_OUTOFBAND | CONFIG_FILE_SDR | CONFIG_FILE_TIME | CONFIG_FILE_HOSTRANGE,
                          CONFIG_FILE_TOOL_IPMI_FRU,
                          &config_file_data) < 0)
     {
