@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2012 FreeIPMI Core Team
+ * Copyright (C) 2003-2013 FreeIPMI Core Team
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,8 +16,8 @@
  * 
  */
 
-#ifndef _IPMI_DEVICE_TYPES_SPEC_H
-#define _IPMI_DEVICE_TYPES_SPEC_H
+#ifndef IPMI_DEVICE_TYPES_SPEC_H
+#define IPMI_DEVICE_TYPES_SPEC_H
 
 #ifdef __cplusplus
 extern "C" {
@@ -281,4 +281,4 @@ extern unsigned int ipmi_device_type_modifier_other_unspecified_device_max_index
 }
 #endif
 
-#endif
+#endif /* IPMI_DEVICE_TYPES_SPEC_H */
